==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/GridFilterDialogViewModelGroupingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelGroupingDescription } from "./GridFilterDialogViewModelGroupingDescription";
/**
 * @hidden
 */
export let GridFilterDialogViewModelGroupingDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogViewModelGroupingDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogViewModelGroupingDescriptionMetadata.a == null) {
                GridFilterDialogViewModelGroupingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogViewModelGroupingDescriptionMetadata.c(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
            }
            if (a.k(GridFilterDialogViewModelGroupingDescriptionMetadata.a)) {
                return;
            }
            a.ab(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
        static c(a) {
            a.item("StartIndex", "Number:int");
            a.item("EndIndex", "Number:int");
            a.item("IsOrGrouping", "Boolean");
        }
        static d(a) {
            GridFilterDialogViewModelGroupingDescriptionMetadata.b(a);
            a.ad("GridFilterDialogViewModelGrouping", () => new GridFilterDialogViewModelGroupingDescription());
            a.ac("GridFilterDialogViewModelGrouping", GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
    }
    GridFilterDialogViewModelGroupingDescriptionMetadata.$t = markType(GridFilterDialogViewModelGroupingDescriptionMetadata, 'GridFilterDialogViewModelGroupingDescriptionMetadata');
    GridFilterDialogViewModelGroupingDescriptionMetadata.a = null;
    return GridFilterDialogViewModelGroupingDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/GridFilterDialogViewModelGroupingDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridFilterDialogViewModelGroupingDescription } from "./GridFilterDialogViewModelGroupingDescription";
/**
 * @hidden
 */
export let GridFilterDialogViewModelGroupingDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridFilterDialogViewModelGroupingDescriptionMetadata extends Base {
        static b(a) {
            if (GridFilterDialogViewModelGroupingDescriptionMetadata.a == null) {
                GridFilterDialogViewModelGroupingDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridFilterDialogViewModelGroupingDescriptionMetadata.c(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
            }
            if (a.k(GridFilterDialogViewModelGroupingDescriptionMetadata.a)) {
                return;
            }
            a.ac(GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
        static c(a) {
            a.item("StartIndex", "Number:int");
            a.item("EndIndex", "Number:int");
            a.item("IsOrGrouping", "Boolean");
        }
        static d(a) {
            GridFilterDialogViewModelGroupingDescriptionMetadata.b(a);
            a.ae("GridFilterDialogViewModelGrouping", () => new GridFilterDialogViewModelGroupingDescription());
            a.ad("GridFilterDialogViewModelGrouping", GridFilterDialogViewModelGroupingDescriptionMetadata.a);
        }
    }
    GridFilterDialogViewModelGroupingDescriptionMetadata.$t = markType(GridFilterDialogViewModelGroupingDescriptionMetadata, 'GridFilterDialogViewModelGroupingDescriptionMetadata');
    GridFilterDialogViewModelGroupingDescriptionMetadata.a = null;
    return GridFilterDialogViewModelGroupingDescriptionMetadata;
})();
